@@ -8,6 +8,10 @@ function (n, Ac, p = seq(0, 0.5, 0.01), Plots = TRUE)
     ASN.semi = pbinom(Ac, n, p) + (1 - pbinom(Ac + 1, n + 1, 
         p)) * ((Ac + 1)/(n * p))
     ASN.semi = n * ASN.semi
+    if (any(p == 0)) {
+        ASN.semi[p == 0] = n
+        ASN.full[p == 0] = n - Ac
+    }
     if (Plots) {
         plot(ASN.full ~ p, type = "l", ylim = c(1, n), ylab = "ASN", 
             col = "red", lty = 2)
@@ -15,8 +19,8 @@ function (n, Ac, p = seq(0, 0.5, 0.01), Plots = TRUE)
         plot(ASN.semi ~ p, type = "l", ylim = c(1, n), ylab = "", 
             col = "blue", lty = 1)
         legend("topright", legend = c("Fully Curtailed ASN", 
-            "Sumi-curtailed ASN"), lty = 2:1, col = c("red", 
+            "Semi-curtailed ASN"), lty = 2:1, col = c("red", 
             "blue"))
     }
-    cbind(p, ASN.semi, ASN.full)
+    return(data.frame(p, ASN.semi, ASN.full))
 }
