@@ -18,16 +18,12 @@ function (N, n1, n2, Ac1, Re1, Ac2, p = seq(0, 0.25, 0.005),
         p))
     AOQ = (p * Pa1 * (N - n1) + p * Pa2 * (N - n1 - n2))/N
     ATI = n1 * Pa1 + (n1 + n2) * Pa2 + (1 - OC) * N
-    results = cbind(p, Pa1, Pa2, OC, ASN, AOQ, ATI)
+    results = list(p = p, OC = OC, ASN = ASN, AOQ = AOQ, ATI = ATI, 
+        Pa1 = Pa1, Pa2 = Pa2)
+    class(results) = "AccSampPlan"
     if (Plots) {
         par(mfrow = c(2, 2))
-        plot(OC ~ p, type = "l", ylab = "Probability of Acceptance", 
-            xlab = "Fraction Nonconforming p")
-        plot(ASN ~ p, type = "l", ylab = "Uncurtailed average sample size", 
-            xlab = "Fraction Nonconforming p")
-        plot(AOQ ~ p, type = "l", ylab = "AOQ", xlab = "Fraction Nonconforming p")
-        title(paste("AOQL = ", formatC(max(AOQ))))
-        plot(ATI ~ p, type = "l", ylab = "ATI", xlab = "Fraction Nonconforming p")
-        par(mfrow = c(1, 1))
+        plot(results)
     }
+    return(results)
 }
